@@ -3,47 +3,45 @@ use core::str::FromStr;
 use crate::heapless::String;
 use crate::uluru::LRUCache;
 
-pub trait History<const COMMAND_LEN: usize> {
+pub trait History<const CMD_LEN: usize> {
     fn reset(&mut self);
     fn push(&mut self, command: &str) -> Result<(), ()>;
-    fn go_back(&mut self) -> Option<String<COMMAND_LEN>>;
-    fn go_forward(&mut self) -> Option<String<COMMAND_LEN>>;
+    fn go_back(&mut self) -> Option<String<CMD_LEN>>;
+    fn go_forward(&mut self) -> Option<String<CMD_LEN>>;
 }
 
 pub struct NoHistory;
 
-impl<const COMMAND_LEN: usize> History<COMMAND_LEN> for NoHistory {
+impl<const CMD_LEN: usize> History<CMD_LEN> for NoHistory {
     fn reset(&mut self) {}
 
     fn push(&mut self, _command: &str) -> Result<(), ()> {
         Ok(())
     }
 
-    fn go_back(&mut self) -> Option<String<COMMAND_LEN>> {
+    fn go_back(&mut self) -> Option<String<CMD_LEN>> {
         None
     }
 
-    fn go_forward(&mut self) -> Option<String<COMMAND_LEN>> {
+    fn go_forward(&mut self) -> Option<String<CMD_LEN>> {
         None
     }
 }
 
 #[derive(Default)]
-pub struct LRUHistory<const COMMAND_LEN: usize, const HISTORY_LEN: usize> {
-    history: LRUCache<String<COMMAND_LEN>, HISTORY_LEN>,
+pub struct LRUHistory<const CMD_LEN: usize, const CAP: usize> {
+    history: LRUCache<String<CMD_LEN>, CAP>,
     cursor: usize,
 }
 
-impl<const COMMAND_LEN: usize, const HISTORY_LEN: usize> History<COMMAND_LEN>
-    for LRUHistory<COMMAND_LEN, HISTORY_LEN>
-{
+impl<const CMD_LEN: usize, const CAP: usize> History<CMD_LEN> for LRUHistory<CMD_LEN, CAP> {
     fn reset(&mut self) {
         self.cursor = 0;
         self.history = LRUCache::default();
     }
 
     fn push(&mut self, command: &str) -> Result<(), ()> {
-        if command.len() > 0 && HISTORY_LEN > 0 {
+        if command.len() > 0 && CAP > 0 {
             if self.history.find(|item| item.as_str() == command).is_none() {
                 let history_entry = String::from_str(command)?;
                 self.history.insert(history_entry);
@@ -53,7 +51,7 @@ impl<const COMMAND_LEN: usize, const HISTORY_LEN: usize> History<COMMAND_LEN>
         Ok(())
     }
 
-    fn go_back(&mut self) -> Option<String<COMMAND_LEN>> {
+    fn go_back(&mut self) -> Option<String<CMD_LEN>> {
         if self.history.len() == 0 || self.cursor == self.history.len() {
             None
         } else {
@@ -63,7 +61,7 @@ impl<const COMMAND_LEN: usize, const HISTORY_LEN: usize> History<COMMAND_LEN>
         }
     }
 
-    fn go_forward(&mut self) -> Option<String<COMMAND_LEN>> {
+    fn go_forward(&mut self) -> Option<String<CMD_LEN>> {
         if self.cursor == 0 || self.history.len() == 0 {
             None
         } else {
